@@ -52,7 +52,7 @@ path.chdir = lfs.chdir
 --- is this a directory?
 -- @string P A file path
 function path.isdir(P)
-	assert_string(1,P)
+    assert_string(1,P)
     if P:match("\\$") then
         P = P:sub(1,-2)
     end
@@ -62,14 +62,14 @@ end
 --- is this a file?.
 -- @string P A file path
 function path.isfile(P)
-	assert_string(1,P)
+    assert_string(1,P)
     return attrib(P,'mode') == 'file'
 end
 
 -- is this a symbolic link?
 -- @string P A file path
 function path.islink(P)
-	assert_string(1,P)
+    assert_string(1,P)
     if link_attrib then
         return link_attrib(P,'mode')=='link'
     else
@@ -80,7 +80,7 @@ end
 --- return size of a file.
 -- @string P A file path
 function path.getsize(P)
-	assert_string(1,P)
+    assert_string(1,P)
     return attrib(P,'size')
 end
 
@@ -88,14 +88,14 @@ end
 -- @string P A file path
 -- @return the file path if it exists, nil otherwise
 function path.exists(P)
-	assert_string(1,P)
+    assert_string(1,P)
     return attrib(P,'mode') ~= nil and P
 end
 
 --- Return the time of last access as the number of seconds since the epoch.
 -- @string P A file path
 function path.getatime(P)
-	assert_string(1,P)
+    assert_string(1,P)
     return attrib(P,'access')
 end
 
@@ -108,7 +108,7 @@ end
 ---Return the system's ctime.
 -- @string P A file path
 function path.getctime(P)
-	assert_string(1,P)
+    assert_string(1,P)
     return path.attrib(P,'change')
 end
 
@@ -117,7 +117,7 @@ local function at(s,i)
     return sub(s,i,i)
 end
 
-path.is_windows = utils.dir_separator == '\\'
+path.is_windows = utils.is_windows
 
 local other_sep
 -- !constant sep is the directory separator for this platform.
@@ -128,7 +128,7 @@ else
     path.sep = '/'
     path.dirsep = ':'
 end
-local sep,dirsep = path.sep,path.dirsep
+local sep = path.sep
 
 --- are we running Windows?
 -- @class field
@@ -165,7 +165,7 @@ end
 -- @string[opt] pwd optional start path to use (default is current dir)
 function path.abspath(P,pwd)
     assert_string(1,P)
-	if pwd then assert_string(2,pwd) end
+    if pwd then assert_string(2,pwd) end
     local use_pwd = pwd ~= nil
     if not use_pwd and not currentdir then return P end
     P = P:gsub('[\\/]$','')
@@ -205,7 +205,7 @@ end
 -- @string P A file path
 function path.dirname(P)
     assert_string(1,P)
-    local p1,p2 = path.splitpath(P)
+    local p1 = path.splitpath(P)
     return p1
 end
 
@@ -213,7 +213,7 @@ end
 -- @string P A file path
 function path.basename(P)
     assert_string(1,P)
-    local p1,p2 = path.splitpath(P)
+    local _,p2 = path.splitpath(P)
     return p2
 end
 
@@ -221,7 +221,7 @@ end
 -- @string P A file path
 function path.extension(P)
     assert_string(1,P)
-    local p1,p2 = path.splitext(P)
+    local _,p2 = path.splitext(P)
     return p2
 end
 
@@ -301,7 +301,7 @@ function path.normpath(P)
     else
         -- According to POSIX, in path start '//' and '/' are distinct,
         -- but '///+' is equivalent to '/'.
-        if P:match '^//' and at(P, 3) ~= '/' then 
+        if P:match '^//' and at(P, 3) ~= '/' then
             anchor = '//'
             P = P:sub(3)
         elseif at(P, 1) == '/' then
@@ -326,19 +326,12 @@ function path.normpath(P)
     return P
 end
 
-local function ATS (P)
-    if at(P,#P) ~= path.sep then
-        P = P..path.sep
-    end
-    return path.normcase(P)
-end
-
 --- relative path from current directory or optional start point
 -- @string P a path
 -- @string[opt] start optional start point (default current directory)
 function path.relpath (P,start)
     assert_string(1,P)
-	if start then assert_string(2,start) end
+    if start then assert_string(2,start) end
     local split,normcase,min,append = utils.split, path.normcase, math.min, table.insert
     P = normcase(path.abspath(P,start))
     start = start or currentdir()
